CardData class

Constructors

CardData({String cardNumber = '', String expiredDate = '', String cardHolderName = '', String cvc = '', CardType? cardType})

Properties

cardHolderName String
getter/setter pair
cardNumber String
getter/setter pair
cardType CardType?
getter/setter pair
cvc String
getter/setter pair
expiredDate String
getter/setter pair
expiredMonth String
no setter
expiredYear String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited