CreditCardDarkTheme class

Implemented types

Constructors

CreditCardDarkTheme()

Properties

backgroundColor Color
getter/setter pairoverride
borderColor Color
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
labelColor Color
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor Color
getter/setter pairoverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited