CreditCardForm class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CreditCardForm
Constructors
- CreditCardForm({Key? key, CreditCardTheme? theme, required dynamic onChanged(CardData), String? cardNumberLabel, String? cardHolderLabel, bool? hideCardHolder = false, bool? enableScanner = false, Widget? scannerIcon, CardScanOptions? scanOptions, String? expiredDateLabel, String? cvcLabel, Widget? cvcIcon, int? cardNumberLength = 16, int? cvcLength = 4, double fontSize = 16, required CardDataInputController controller})
-
const
Properties
- cardHolderLabel → String?
-
final
- cardNumberLabel → String?
-
final
- cardNumberLength → int?
-
final
- controller → CardDataInputController
-
final
- cvcIcon → Widget?
-
final
- cvcLabel → String?
-
final
- cvcLength → int?
-
final
- enableScanner → bool?
-
final
- expiredDateLabel → String?
-
final
- fontSize → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideCardHolder → bool?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onChanged → dynamic Function(CardData)
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scannerIcon → Widget?
-
final
- scanOptions → CardScanOptions?
-
final
- theme → CreditCardTheme?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CreditCardForm> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited